@@ -1,41 +1,45 @@
 #line 1 "inc/Module/Install/Base.pm - /usr/local/share/perl/5.8.7/Module/Install/Base.pm"
 package Module::Install::Base;
 
+$VERSION = '0.58';
+
 # Suspend handler for "redefined" warnings
 BEGIN {
 	my $w = $SIG{__WARN__};
 	$SIG{__WARN__} = sub { $w };
 }
 
-#line 36
+### This is the ONLY module that shouldn't have strict on
+# use strict;
+
+#line 41
 
 sub new {
     my ($class, %args) = @_;
 
-    foreach my $method (qw(call load)) {
+    foreach my $method ( qw(call load) ) {
         *{"$class\::$method"} = sub {
-            +shift->_top->$method(@_);
+            shift()->_top->$method(@_);
         } unless defined &{"$class\::$method"};
     }
 
-    bless(\%args, $class);
+    bless( \%args, $class );
 }
 
-#line 56
+#line 61
 
 sub AUTOLOAD {
     my $self = shift;
-
     local $@;
     my $autoload = eval { $self->_top->autoload } or return;
     goto &$autoload;
 }
 
-#line 72
+#line 76
 
 sub _top { $_[0]->{_top} }
 
-#line 85
+#line 89
 
 sub admin {
     $_[0]->_top->{admin} or Module::Install::Base::FakeAdmin->new;
@@ -63,4 +67,4 @@ BEGIN {
 
 1;
 
-#line 134
+#line 138
